#!/bin/bash

. util.sh
. .env

kibana_host="localhost:$KIBANA_PORT"
es_host="localhost:$ES_PORT1"


function setDefaultIndex(){

curl --location --request POST "http://$kibana_host/api/kibana/settings" \
--header 'kbn-version: 7.12.0' \
--header 'Content-Type: application/json' \
--data-raw "{\"changes\":{\"defaultIndex\":\"$1\"}}"

}

function addILMPolicy() {
curl -XPOST "http://$es_host/_ilm/policy/service-log" \
--header 'Content-Type: application/json' \
--data-raw '{"policy":{"phases":{"hot":{"min_age":"0ms","actions":{"set_priority":{"priority":100}}},"delete":{"min_age":"365d","actions":{"delete":{"delete_searchable_snapshot":true}}}}}}'
}

function contain() {
  if [ "$(echo "$1" | grep -c "$2")" -gt 0 ]; then return 0; else return 1; fi
}

function uploadConfig() {
resp=$(curl -s -XPOST "$kibana_host/api/saved_objects/_import?createNewCopies=true" --form "file=@kibana/export.ndjson" --header 'kbn-xsrf: true')
if contain "$resp" 'success'; then\
  echo "config upload succeed";
else echo "config upload failed" ;
fi
}

function notHealth() {
resp=$(curl -sIL -m 5 -w "%{http_code}" -o /dev/null -XGET "$kibana_host/api/features" --header 'kbn-xsrf: true')
if [ "$resp" == 200 ]; then return 1
else return 0
fi
}

start=$(date +%s)
while notHealth
do
end=$(date +%s)
take=$(( end - start ))
red "Kibana not ready yet, waitTime: $take"
sleep 1s
done
green "======================================="
green "Kibana is ready. Initialization begins."
green "======================================="
addILMPolicy
uploadConfig
green "Initialization completed."
green "Visit the following website to discover data"
green "http://$kibana_host/app/discover"
green "End"

